@@ -121,23 +121,30 @@ class ControlsPosition(StringListArgument):
 
 
 _classes = {
-    "A-24": ("covmatic_stations.a.technogenetics", "StationATechnogenetics24", NumSamples),
-    "A": ("covmatic_stations.a.technogenetics", "StationATechnogenetics48", NumSamples),
-    "A-Bioer": ("covmatic_stations.a.aBioerPreparation", "StationABioerPreparation"),
-    "B": ("covmatic_stations.b.technogenetics", "StationBTechnogenetics", NumSamples),
+    "A-24":         ("covmatic_stations.a.technogenetics", "StationATechnogenetics24", NumSamples),
+    "A":            ("covmatic_stations.a.technogenetics", "StationATechnogenetics48", NumSamples),
+    "A-Saliva":     ("covmatic_stations.a.technogenetics", "StationATechnogenetics48Saliva", NumSamples),
+    "A-Bioer":      ("covmatic_stations.a.aBioerPreparation", "StationABioerPreparation"),
+    "B":            ("covmatic_stations.b.technogenetics", "StationBTechnogenetics", NumSamples),
     "B-Paired Pipette": ("covmatic_stations.b.technogenetics_paired_pipette", "StationBTechnogeneticsPairedPipette", NumSamples),
-    "C": ("covmatic_stations.c.technogenetics", "StationCTechnogenetics", NumSamples),
+    "B-Saliva":     ("covmatic_stations.b.technogenetics", "StationBTechnogeneticsSaliva", NumSamples),
+    "B-Saliva-Paired Pipette":  ("covmatic_stations.b.technogenetics_paired_pipette", "StationBTechnogeneticsSalivaPairedPipette", NumSamples),
+    "C":            ("covmatic_stations.c.technogenetics", "StationCTechnogenetics", NumSamples),
     "Elution Removal": ("covmatic_stations.b.technogenetics_short", "StationBTechnogeneticsElutionRemoval", NumSamples, NumCycles),
     "Wash B Removal": ("covmatic_stations.b.technogenetics_short", "StationBTechnogeneticsWashBRemoval", NumSamples, NumCycles),
-    "BioerPrep": ("covmatic_stations.bioer.Bioer_preparation", "BioerPreparation", NumSamples),
-    "BioerPCR": ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcr", NumSamples, ControlsPosition),
+    "BioerPrep":    ("covmatic_stations.bioer.Bioer_preparation", "BioerPreparation", NumSamples),
+    "BioerPCR":     ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcr", NumSamples, ControlsPosition),
     "BioerPCR-Technogenetics": ("covmatic_stations.bioer.Bioer_full_dw", "BioerPreparationToPcrTechogenetics", NumSamples, ControlsPosition)
 }
 
 
+# Adding 'start_at' field if requested
 if Args().start_at:
     _classes = {k: (*v, StartAt) for k, v in _classes.items()}
 
+# Filtering shown protocols based on configuration
+if Args().protocols_to_show != "":
+    _classes = {k: v for k, v in _classes.items() if k in [p.strip() for p in Args().protocols_to_show.split(',')]}
 
 def protocol_gen(cls: str, log_level: str = "INFO", apiLevel='2.7', **prot_kwargs) -> str:
     if cls not in _classes:
